@@ -27,20 +27,21 @@ class NelsonAalenFitter(object):
           self._variance_f = self._variance_f_discrete
           self._additive_f = self._additive_f_discrete
 
-    def fit(self, event_times,censorship=None, timeline=None, columns=['NA-estimate'], alpha=None, insert_0=True):
+    def fit(self, event_times,censorship=None, timeline=None, label='NA-estimate', alpha=None, insert_0=True):
         """
         Parameters:
-          event_times: an (n,1) array of times that the death event occured at
+          event_times: an array, or pd.Series, of length n of times that the death event occured at
           timeline: return the best estimate at the values in timelines (postively increasing)
-          columns: a length 1 array to name the column of the estimate.
+          censorship: an array, or pd.Series, of length n -- True if the the death was observed, False if the event
+             was lost (right-censored). Defaults all True if censorship==None
+          label: a string to name the column of the estimate.
           alpha: the alpha value in the confidence intervals. Overrides the initializing
              alpha for this call to fit only.
           insert_0: add a leading 0 (if not present) in the timeline.
 
-
         Returns:
-          DataFrame with index either event_times or timelines (if not None), with
-          values as the NelsonAalen estimate
+          self, with new properties like 'survival_function_'.
+
         """
 
         if censorship is None:
@@ -62,8 +63,9 @@ class NelsonAalenFitter(object):
 
         cumulative_hazard_, cumulative_sq_ = _additive_estimate(self.event_times, self.timeline,
                                                                      self._additive_f, self._variance_f )
-        self.cumulative_hazard_ = pd.DataFrame(cumulative_hazard_, columns=columns)
+        self.cumulative_hazard_ = pd.DataFrame(cumulative_hazard_, columns=[label])
         self.confidence_interval_ = self._bounds(cumulative_sq_[:,None],alpha)
+        self.predict = _predict(self, "cumulative_hazard_", label)
         self.plot = plot_dataframes(self, "cumulative_hazard_")
         self.plot_cumulative_hazard = self.plot
         self.plot_hazard = plot_dataframes(self, 'hazard_')
@@ -82,16 +84,14 @@ class NelsonAalenFitter(object):
     def _variance_f_smooth(self, population, deaths):
         """TODO: speed this up"""
         df = pd.DataFrame( {'N':population, 'd':deaths})
-        return df.apply( lambda N_d: np.sum( [1./(N_d[0]-i)**2 for i in range(int(N_d[1]))]), axis=1 )
-        #return df.apply( lambda (N,d): np.sum([1./(N-i)**2 for i in xrange(int(d))]), axis=1 )
+        return df.apply( lambda N_d: np.sum((1./(N_d[0]-i)**2 for i in range(int(N_d[1])))), axis=1 )
 
     def _variance_f_discrete(self, population, deaths):
         return 1.*(population-deaths)*deaths/population**3
 
     def _additive_f_smooth(self, population, deaths):
         df = pd.DataFrame( {'N':population, 'd':deaths})
-        return df.apply( lambda N_d: np.sum([1./(N_d[0]-i) for i in range(int(N_d[1]))]), axis=1 )
-        #return df.apply( lambda (N,d): np.sum([1./(N-i) for i in xrange(int(d))]), axis=1 )
+        return df.apply( lambda N_d: np.sum((1./(N_d[0]-i) for i in range(int(N_d[1])))), axis=1 )
 
     def _additive_f_discrete(self, population, deaths):
        return (1.*deaths/population).replace([np.inf],0)
@@ -133,8 +133,7 @@ class NelsonAalenFitter(object):
 
     def __repr__(self):
       try:
-        s="""<lifelines.NelsonAalenFitter: fitted with %d observations, %d censored. \n"""%(self.censorship.shape[0], (~self.censorship).sum()) 
-        s += self.cumulative_hazard_.head(4).to_string(col_space=15) + "\n... >"
+        s="""<lifelines.NelsonAalenFitter: fitted with %d observations, %d censored.>"""%(self.censorship.shape[0], (~self.censorship).sum()) 
       except AttributeError as e:
         s= """<lifelines.NelsonAalenFitter>"""
       return s
@@ -144,21 +143,21 @@ class KaplanMeierFitter(object):
   def __init__(self, alpha=0.95):
        self.alpha = alpha
 
-  def fit(self, event_times, censorship=None, timeline=None, columns=['KM-estimate'], alpha=None, insert_0=True):
+  def fit(self, event_times, censorship=None, timeline=None, label='KM-estimate', alpha=None, insert_0=True):
        """
        Parameters:
-         event_times: an (n,1) array of times that the death event occured at
-         timeline: return the best estimate at the values in timelines (postively increasing)
-         censorship: an (n,1) array of booleans -- True if the the death was observed, False if the event
-            was lost (right-censored). Defaults all True if censorship==None
-         columns: a length 1 array to name the column of the estimate.
-         alpha: the alpha value in the confidence intervals. Overrides the initializing
-            alpha for this call to fit only.
-         insert_0: add a leading 0 (if not present) in the timeline.
+          event_times: an array, or pd.Series, of length n of times that the death event occured at
+          timeline: return the best estimate at the values in timelines (postively increasing)
+          censorship: an array, or pd.Series, of length n -- True if the the death was observed, False if the event
+             was lost (right-censored). Defaults all True if censorship==None
+          label: a string to name the column of the estimate.
+          alpha: the alpha value in the confidence intervals. Overrides the initializing
+             alpha for this call to fit only.
+          insert_0: add a leading 0 (if not present) in the timeline.
 
        Returns:
-         DataFrame with index either event_times or timelines (if not None), with
-         values under column_name with the KaplanMeier estimate
+          self, with new properties like 'survival_function_'.
+
        """
        #set to all observed if censorship is none
        if censorship is None:
@@ -181,9 +180,9 @@ class KaplanMeierFitter(object):
        log_survival_function, cumulative_sq_ = _additive_estimate(self.event_times, self.timeline,
                                                                   self._additive_f, self._additive_var)
 
-       self.survival_function_ = pd.DataFrame(np.exp(log_survival_function), columns=columns)
-       #self.median_ = median_survival_times(self.survival_function_)
+       self.survival_function_ = pd.DataFrame(np.exp(log_survival_function), columns=[label])
        self.confidence_interval_ = self._bounds(cumulative_sq_[:,None],alpha)
+       self.predict = _predict(self, "survival_function_", label)
        self.plot = plot_dataframes(self, "survival_function_")
        self.plot_survival_function = self.plot
        self.median_ = median_survival_times(self.survival_function_)
@@ -208,12 +207,23 @@ class KaplanMeierFitter(object):
       return (1.*deaths/(population*(population-deaths))).replace([np.inf],0)
 
   def __repr__(self):
-    try:
-      s="""<lifelines.KaplanMeierFitter: fitted with %d observations, %d censored. \n"""%(self.censorship.shape[0], (~self.censorship).sum()) 
-      s += self.survival_function_.head(4).to_string(col_space=15) + "\n... >"
-    except AttributeError as e:
-      s= """<lifelines.KaplanMeierFitter>"""
-    return s
+      try:
+        s="""<lifelines.KaplanMeierFitter: fitted with %d observations, %d censored>"""%(self.censorship.shape[0], (~self.censorship).sum()) 
+      except AttributeError as e:
+        s= """<lifelines.KaplanMeierFitter>"""
+      return s
+
+
+def _predict(self, estimate, label):
+    def predict(time):
+      """
+      Predict the estimate at certain times
+
+      Parameters:
+        time: an array of times to predict the estimate at 
+      """
+      return map(lambda t: getattr(self,estimate).ix[:t].iloc[-1][label], time)
+    return predict
 
 
 def _additive_estimate(events, timeline, _additive_f, _additive_var):
